@@ -4,8 +4,13 @@
   (:use #:closer-common-lisp #:lispworks)
   (:export
    #:*symbol-access*
+   #:activate-layer
+   #:activate-layer-using-class
    #:apply-with-layers
+   #:call-next-layered-method
    #:class-layer
+   #:deactivate-layer
+   #:deactivate-layer-using-class
    #:define-layered-class
    #:define-layered-function
    #:define-layered-method
@@ -16,17 +21,21 @@
    #:ensure-layered-function
    #:ensure-layered-method
    #:find-layer
+   #:find-layer-class
+   #:find-singleton
    #:funcall-with-layers
    #:make-special-symbol
    #:layer-active-p
+   #:layer-makunbound
    #:layer-name
-   #:layer-prototype
    #:layered-access-class
    #:layered-class
    #:layered-direct-slot-definition
    #:layered-effective-slot-definition
    #:layered-effective-slot-definition-in-layers
+   #:lfmakunbound
    #:partial-class
+   #:singleton-class
    #:slot-definition-layer
    #:slot-definition-layeredp
    #:slot-definition-layers
@@ -48,8 +57,13 @@
    #:standard-class-in-layer
    #:standard-direct-slot-definition-in-layer
    #:standard-effective-slot-definition-in-layers
+   #:standard-layer-class
+   #:standard-layer-object
    #:with-active-layers
+   #:with-active-layers*
    #:with-inactive-layers
+   #:with-special-initargs
+   #:with-special-initargs*
    #:with-symbol-access
    #:without-symbol-access))
 
